pub struct LeaderCachedKvBackend {
check_leader: CheckLeaderRef,
store: KvBackendRef,
cache: ResettableKvBackendRef,
version: AtomicUsize,
name: String,
}Expand description
A cache dedicated to a Leader node, in order to cache some metadata.
To use this cache, the following constraints must be followed:
- The leader node can create this metadata.
- The follower node can create this metadata. The leader node can lazily retrieve the corresponding data through the caching loading mechanism.
- Only the leader node can update this metadata, as the cache cannot detect modifications made to the data on the follower node.
- Only the leader node can delete this metadata for the same reason mentioned above.
Fields
check_leader: CheckLeaderRefstore: KvBackendRefcache: ResettableKvBackendRefversion: AtomicUsizename: StringImplementations
Sourceimpl LeaderCachedKvBackend
impl LeaderCachedKvBackend
pub fn new(check_leader: CheckLeaderRef, store: KvBackendRef) -> Self
Sourcepub fn with_always_leader(store: KvBackendRef) -> Self
pub fn with_always_leader(store: KvBackendRef) -> Self
With a leader checker which always returns true when checking, mainly used in test scenarios.
Sourcepub async fn load(&self) -> Result<()>
pub async fn load(&self) -> Result<()>
The caller MUST ensure during the loading, there are no mutation requests reaching the LeaderCachedKvStore.
fn is_leader(&self) -> bool
async fn invalid_key(&self, key: Vec<u8>) -> Result<()>
async fn invalid_keys(&self, keys: Vec<Vec<u8>>) -> Result<()>
fn get_version(&self) -> usize
fn create_new_version(&self) -> usize
fn validate_version(&self, version: usize) -> bool